summaryrefslogtreecommitdiffstats
path: root/tdefile-plugins/torrent/bbase.h
diff options
context:
space:
mode:
Diffstat (limited to 'tdefile-plugins/torrent/bbase.h')
-rw-r--r--tdefile-plugins/torrent/bbase.h6
1 files changed, 3 insertions, 3 deletions
diff --git a/tdefile-plugins/torrent/bbase.h b/tdefile-plugins/torrent/bbase.h
index 30da7528..7a4693c6 100644
--- a/tdefile-plugins/torrent/bbase.h
+++ b/tdefile-plugins/torrent/bbase.h
@@ -32,11 +32,11 @@ class TQIODevice;
* check error status that way.
*
* @author Michael Pyne <mpyne@grammarian.homelinux.net>
* @see BInt, BList, BDict, BString, KSharedPtr
*/
-// Derive from KShared to enable use of KSharedPtr.
-class BBase : public KShared
+// Derive from TDEShared to enable use of TDESharedPtr.
+class BBase : public TDEShared
{
public:
@@ -32,11 +32,11 @@ class TQIODevice;
*
* @author Michael Pyne <mpyne@grammarian.homelinux.net>
- * @see BInt, BList, BDict, BString, KSharedPtr
+ * @see BInt, BList, BDict, BString, TDESharedPtr
*/